==> performline-0.1.0.tar.gz: performline-0.1.0/performline/products/common/models.py <==
# Copyright (c) 2016, PerformLine, Inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the company nor the
#       names of its contributors may be used to endorse or promote products
#       derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL PERFORMLINE, INC. BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""Models representing common API objects"""

from __future__ import unicode_literals
from __future__ import absolute_import
from ...models import Model


class Brand(Model):
    """An object for retrieving data from and working with an individual brand."""
    pass

    # def campaigns(self):


class Campaign(Model):
    """An object for retrieving data from and working with an individual campaign."""

    @property
    def brand(self):
        return self.client.brands(id=self.BrandId)

    # def pages(self):
    # def rules(self):


class Rule(Model):
    """An object for retrieving data from and working with an individual rule."""
    pass

    # def brand(self):
    # def campaigns(self):
    # def pages(self):


class TrafficSource(Model):
    """An object for retrieving data from and working with an individual traffic source."""
    pass

==> performline-0.2.1.tar.gz: performline-0.2.1/performline/products/common/models.py <==
# Copyright (c) 2016, PerformLine, Inc.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of the company nor the
#       names of its contributors may be used to endorse or promote products
#       derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL PERFORMLINE, INC. BE LIABLE FOR ANY
# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""Models representing common API objects"""

from __future__ import absolute_import
from ...embedded.stdlib.clients.rest.models import RestModel


class Brand(RestModel):
    """An object for retrieving data from and working with an individual brand."""
    rest_path = '/common/brands/'

    # def campaigns(self):


class Campaign(RestModel):
    """An object for retrieving data from and working with an individual campaign."""
    rest_path = '/common/campaigns/'

    @property
    def brand(self):
        return self.client.brands(id=self.id)

    # def pages(self):
    # def rules(self):


class Rule(RestModel):
    """An object for retrieving data from and working with an individual rule."""
    rest_path = '/common/rules/'

    # def brand(self):
    # def campaigns(self):
    # def pages(self):


class TrafficSource(RestModel):
    """An object for retrieving data from and working with an individual traffic source."""
    rest_path = '/common/trafficsources/'
